@@ -1040,6 +1040,11 @@ class _RequestReceiver(object):
 
         request.save()
 
+# TODO(dustin): The invocation and request are being saved here (confirmed), 
+#               but not found from the queue message-handlers if the current 
+#               request terminates too soon (when we're running 
+#               asynchronously).
+
         _logger.debug("Received request: [%s]", request)
 
         message_parameters = mr.shared_types.QUEUE_MESSAGE_PARAMETERS_CLS(
@@ -1052,11 +1057,14 @@ class _RequestReceiver(object):
 
         return message_parameters
 
-    def process_request(self, message_parameters):
+    def process_request(self, message_parameters, block=True):
         self.__push_request(message_parameters)
-        r = self.__block_for_result(message_parameters)
 
-        return r
+        if block is True:
+            r = self.__block_for_result(message_parameters)
+            return r
+        else:
+            return None
 
 _request_receiver = None
 def get_request_receiver():
